@@ -276,11 +276,19 @@ class PolymorphicParentModelAdmin(admin.ModelAdmin):
         """
         ct_id = int(request.GET.get('ct_id', 0))
         if not ct_id:
-            raise Http404("No ct_id parameter, unable to find admin subclass for path '{0}'.".format(path))
+            # See if the path started with an ID.
+            try:
+                pos = path.find('/')
+                object_id = long(path[0:pos])
+            except ValueError:
+                raise Http404("No ct_id parameter, unable to find admin subclass for path '{0}'.".format(path))
+
+            ct_id = self.model.objects.values_list('polymorphic_ctype_id', flat=True).get(pk=object_id)
+
 
         real_admin = self._get_real_admin_by_ct(ct_id)
         resolver = RegexURLResolver('^', real_admin.urls)
-        resolvermatch = resolver.resolve(path)
+        resolvermatch = resolver.resolve(path)  # May raise Resolver404
         if not resolvermatch:
             raise Http404("No match for path '{0}' in admin subclass.".format(path))
 
@@ -400,8 +408,7 @@ class PolymorphicChildModelAdmin(admin.ModelAdmin):
         #
         # Instead, pass the form unchecked here, because the standard ModelForm will just work.
         # If the derived class sets the model explicitly, respect that setting.
-        if not self.form:
-            kwargs['form'] = self.base_form
+        kwargs.setdefault('form', self.base_form or self.form)
         return super(PolymorphicChildModelAdmin, self).get_form(request, obj, **kwargs)
 
 
@@ -479,11 +486,6 @@ class PolymorphicChildModelAdmin(admin.ModelAdmin):
             return self.base_fieldsets
 
 
-    def get_form(self, request, obj=None, **kwargs):
-        kwargs.setdefault('form', self.base_form)
-        return super(PolymorphicChildModelAdmin, self).get_form(request, obj, **kwargs)
-
-
     def get_subclass_fields(self, request, obj=None):
         # Find out how many fields would really be on the form,
         # if it weren't restricted by declared fields.
@@ -492,7 +494,7 @@ class PolymorphicChildModelAdmin(admin.ModelAdmin):
 
         # By not declaring the fields/form in the base class,
         # get_form() will populate the form with all available fields.
-        form = self.get_form(request, obj, exclude=exclude, form=self.base_form)
+        form = self.get_form(request, obj, exclude=exclude)
         subclass_fields = list(six.iterkeys(form.base_fields)) + list(self.get_readonly_fields(request, obj))
 
         # Find which fields are not part of the common fields.
